about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-nix.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-nix.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-nix.nix7
1 files changed, 4 insertions, 3 deletions
diff --git a/pkgs/development/haskell-modules/configuration-nix.nix b/pkgs/development/haskell-modules/configuration-nix.nix
index c954f06518bc..58ab8024369a 100644
--- a/pkgs/development/haskell-modules/configuration-nix.nix
+++ b/pkgs/development/haskell-modules/configuration-nix.nix
@@ -455,9 +455,10 @@ self: super: builtins.intersectAttrs super {
   # loc and loc-test depend on each other for testing. Break that infinite cycle:
   loc-test = super.loc-test.override { loc = dontCheck self.loc; };
 
   # The test suite tries to run the "fixpoint" executable just built before and
   # fails, probably because the library search paths don't add up and it can't
   # find its own shared library.
   liquid-fixpoint = disableSharedExecutables super.liquid-fixpoint;
+  liquidhaskell = dontCheck (disableSharedExecutables super.liquidhaskell);
 
 }
@@ -455,9 +455,10 @@ self: super: builtins.intersectAttrs super {
   loc-test = super.loc-test.override { loc = dontCheck self.loc; };
 
-  # The test suite tries to run the "fixpoint" executable just built before and
-  # fails, probably because the library search paths don't add up and it can't
-  # find its own shared library.
+  # The test suites try to run the "fixpoint" and "liquid" executables built just
+  # before and fail because the library search paths aren't configured properly.
+  # Also needs https://github.com/ucsd-progsys/liquidhaskell/issues/1038 resolved.
   liquid-fixpoint = disableSharedExecutables super.liquid-fixpoint;